==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/g_group_create.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


$lang['section_create_group'] = 				"create a group";


//HEADER
//$lang['hdr_closed_group'] = 					"closed group";
//$lang['hdr_closed_group_intro'] = 				"only the members of the group can see the group.";
$lang['hdr_group_setup_rules'] = 				"some simple rules";


//SUBMIT BUTTONS
$lang['sub_apply'] = 							"apply";
$lang['sub_hidden_group_radio'] = 				"create a hidden group";
$lang['sub_visible_group_radio'] = 				"create a visible group";
$lang['sub_create_group'] = 					"create your group";


//A HREF TAGS (links)
$lang['href_new_group'] =						"go to your new group now";


//BODY TEXT
$lang['txt_intro'] = 							"What to create a group?";
$lang['txt_intro_help'] = 						"Creating a group is easy. Just agree to the rules below and answer some simple questions. We will create all the defaults you need including groups rules and a group stucture. Please remember to take a moment to see if their is already a group running with the same subject material and mission.";
$lang['txt_hidden_group_intro'] = 				"A hidden group is run by you and is hidden from the node.";
$lang['txt_visible_group_intro'] = 				"To create a visible group you have to either be a non for profit organisation and you have to run it under the terms of your artlces or association or you agree to administrating the group and running yearly elections to elect a council and chair to oversee the group.";
$lang['txt_group_registration_type'] = 			"Membership registration type";
$lang['txt_group_registration_closed'] = 		"No member can join. Only you can add them.";
$lang['txt_group_registration_approved'] = 		"Any member of the node can apply, but you have to approve their membership";
$lang['txt_group_registration_automatic'] = 	"Any member can join without you needing to approve their application";
$lang['txt_age_from'] = 						"from age";
$lang['txt_age_to'] = 							"to age";
$lang['txt_age_any'] = 							"any";
$lang['txt_admin_note'] =						"Is there any other information you want to give to the administrator?";
$lang['txt_group_title'] = 						"What is the name of your group?";
$lang['txt_group_description'] = 				"Give a short description of your group.";
$lang['txt_group_language'] = 					"What language do you want the group contributions to be in?";
$lang['txt_group_age'] = 						"What is, if any the recommended participation age of the membership?";
$lang['txt_group_genre'] = 						"Select the genre that best describes your group.";
$lang['txt_note'] =								"Is there any other information you wish the administrator to know? If so, add it here.";
$lang['txt_group_completed'] = 					"thank you for applying to start a group. The group administrator will message you shourtly.";




//$lang['txt_reg_group_intro'] = 					"A registered member only group is a group that visitors can apply to join. Each visitor can see all the content of the group, but cannot contribute.";
//$lang['txt_open_group_intro'] = 				"An open group is a group that anyone can join and contribute to.";
//$lang['txt_group_rules'] = 						"Check the rules for your group.";
//$lang['txt_completed_closed'] = 				"You can enter your group now. We have started some things for you, so you have a default discussion area and a library. Go into the membership section to invite your friends to join you.";
//$lang['txt_completed_open'] = 					"Your application request has been received by the administrator. They will message you as soon as possible.";
//$lang['txt_completed_reg'] = 					"Your application request has been received by the administrator. They will message you as soon as possible.";

?>

==> aroundme_0_4_2.zip: aroundme_0_4_2/www/aroundme_0_4_2/language/1/am_default/g_group_create.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


$lang['section_create_group'] = 				"create a group";


//HEADER
//$lang['hdr_closed_group'] = 					"closed group";
//$lang['hdr_closed_group_intro'] = 				"only the members of the group can see the group.";
$lang['hdr_group_setup_rules'] = 				"some simple rules";


//SUBMIT BUTTONS
$lang['sub_apply'] = 							"apply";
$lang['sub_hidden_group_radio'] = 				"create a hidden group";
$lang['sub_visible_group_radio'] = 				"create a visible group";
$lang['sub_create_group'] = 					"create your group";


//A HREF TAGS (links)
$lang['href_new_group'] =						"go to your new group now";


//BODY TEXT
$lang['txt_intro'] = 							"What to create a group?";
$lang['txt_intro_help'] = 						"Creating a group is easy. Just agree to the rules below and answer some simple questions. We will create all the defaults you need including groups rules and a group stucture. Please remember to take a moment to see if their is already a group running with the same subject material and mission.";
$lang['txt_hidden_group_intro'] = 				"A hidden group is run by you and is hidden from the node.";
$lang['txt_visible_group_intro'] = 				"To create a visible group you have to either be a non for profit organisation and you have to run it under the terms of your artlces or association or you agree to administrating the group and running yearly elections to elect a council and chair to oversee the group.";
$lang['txt_group_registration_type'] = 			"Membership registration type";
$lang['txt_group_registration_closed'] = 		"No member can join. Only you can add them.";
$lang['txt_group_registration_approved'] = 		"Any member of the node can apply, but you have to approve their membership";
$lang['txt_group_registration_automatic'] = 	"Any member can join without you needing to approve their application";
$lang['txt_age_from'] = 						"from age";
$lang['txt_age_to'] = 							"to age";
$lang['txt_age_any'] = 							"any";
$lang['txt_admin_note'] =						"Is there any other information you want to give to the administrator?";
$lang['txt_group_title'] = 						"What is the name of your group?";
$lang['txt_group_description'] = 				"Give a short description of your group.";
$lang['txt_group_language'] = 					"What language do you want the group contributions to be in?";
$lang['txt_group_age'] = 						"What is, if any the recommended participation age of the membership?";
$lang['txt_group_genre'] = 						"Select the genre that best describes your group.";
$lang['txt_note'] =								"Is there any other information you wish the administrator to know? If so, add it here.";
$lang['txt_group_completed_pending'] = 			"Thank you for applying to start a group. The group administrator will message you shourtly.";
$lang['txt_group_completed'] = 					"Your group has been created. By default, when people join your group they will not be able to see anything. You need to assign them privileges to see content that you create. To give them privilege go to the 'group acs' (Access Control System) and configure your roles and the privileges you wish to assign to them. See the 'groups' section in the user manual (in the help group library) if you need to know more.";





?>
